@@ -604,6 +604,11 @@ func aideDaemonset(dsName string, fi *fileintegrityv1alpha1.FileIntegrity) *apps
 										},
 									},
 								},
+								{
+									// Needed for friendlier memory reporting as long as we are on golang < 1.16
+									Name:  "GODEBUG",
+									Value: "madvdontneed=1",
+								},
 							},
 							VolumeMounts: []corev1.VolumeMount{
 								{
@@ -612,6 +617,10 @@ func aideDaemonset(dsName string, fi *fileintegrityv1alpha1.FileIntegrity) *apps
 								},
 								{
 									Name:      "config",
+									MountPath: "/config",
+								},
+								{
+									Name:      "tmp",
 									MountPath: "/tmp",
 								},
 							},
@@ -626,6 +635,16 @@ func aideDaemonset(dsName string, fi *fileintegrityv1alpha1.FileIntegrity) *apps
 								},
 							},
 						},
+						{
+							// for pprof
+							Name: "tmp",
+							VolumeSource: corev1.VolumeSource{
+								EmptyDir: &corev1.EmptyDirVolumeSource{
+									Medium:    corev1.StorageMediumDefault,
+									SizeLimit: nil,
+								},
+							},
+						},
 						{
 							Name: "config",
 							VolumeSource: corev1.VolumeSource{
@@ -663,5 +682,7 @@ func daemonArgs(dsName string, fi *fileintegrityv1alpha1.FileIntegrity) []string
 		"--namespace=" + fi.Namespace,
 		"--interval=" + getGracePeriod(fi),
 		"--debug=" + getDebug(fi),
+		"--aideconfigdir=/config",
+		//"--pprof=true",
 	}
 }
